# Document with Links

This document references [[Link1]] for more information.

Also check [[Link2|Different Display Name]] for additional details.

See [[Link1#Section]] for specific information about sections.